@@ -17,7 +17,7 @@ use self::{
     window::WindowEvent,
 };
 
-use crate::{audio::event::AudioDeviceEvent, bind, Sdl, Video};
+use crate::{audio::event::AudioDeviceEvent, bind, EnumInt, Sdl, Video};
 
 pub mod app;
 pub mod drop;
@@ -149,94 +149,92 @@ impl<'video> EventBox<'video> {
 
     fn handle_event(&self, event: bind::SDL_Event) {
         let ty = unsafe { event.type_ };
-        match ty {
-            bind::SDL_EventType_SDL_QUIT => {
+        match ty as EnumInt {
+            bind::SDL_QUIT => {
                 let quit: QuitEvent = unsafe { event.quit }.into();
                 self.quit_event_handlers.call_handlers(quit);
             }
-            bind::SDL_EventType_SDL_WINDOWEVENT => {
+            bind::SDL_WINDOWEVENT => {
                 let window: WindowEvent = unsafe { event.window }.into();
                 self.window_event_handlers.call_handlers(window);
             }
-            bind::SDL_EventType_SDL_KEYDOWN | bind::SDL_EventType_SDL_KEYUP => {
+            bind::SDL_KEYDOWN | bind::SDL_KEYUP => {
                 let keyboard: KeyboardEvent = unsafe { event.key }.into();
                 self.keyboard_event_handlers.call_handlers(keyboard);
             }
-            bind::SDL_EventType_SDL_TEXTINPUT => {
+            bind::SDL_TEXTINPUT => {
                 let input: TextInputEvent = unsafe { event.text }.into();
                 self.input_event_handlers.call_handlers(input);
             }
-            bind::SDL_EventType_SDL_TEXTEDITING => {
+            bind::SDL_TEXTEDITING => {
                 let editing: TextEditingEvent = unsafe { event.edit }.into();
                 self.editing_event_handlers.call_handlers(editing);
             }
-            bind::SDL_EventType_SDL_MOUSEMOTION => {
+            bind::SDL_MOUSEMOTION => {
                 let motion: MouseMotionEvent = unsafe { event.motion }.into();
                 let mouse = MouseEvent::Motion(motion);
                 self.mouse_event_handlers.call_handlers(mouse);
             }
-            bind::SDL_EventType_SDL_MOUSEBUTTONDOWN | bind::SDL_EventType_SDL_MOUSEBUTTONUP => {
+            bind::SDL_MOUSEBUTTONDOWN | bind::SDL_MOUSEBUTTONUP => {
                 let button: MouseButtonEvent = unsafe { event.button }.into();
                 let mouse = MouseEvent::Button(button);
                 self.mouse_event_handlers.call_handlers(mouse);
             }
-            bind::SDL_EventType_SDL_MOUSEWHEEL => {
+            bind::SDL_MOUSEWHEEL => {
                 let wheel: MouseWheelEvent = unsafe { event.wheel }.into();
                 let mouse = MouseEvent::Wheel(wheel);
                 self.mouse_event_handlers.call_handlers(mouse);
             }
-            bind::SDL_EventType_SDL_CONTROLLERAXISMOTION => {
+            bind::SDL_CONTROLLERAXISMOTION => {
                 let con: ControllerEvent = unsafe { event.caxis }.into();
                 self.controller_event_handlers.call_handlers(con);
             }
-            bind::SDL_EventType_SDL_CONTROLLERBUTTONDOWN
-            | bind::SDL_EventType_SDL_CONTROLLERBUTTONUP => {
+            bind::SDL_CONTROLLERBUTTONDOWN | bind::SDL_CONTROLLERBUTTONUP => {
                 let con: ControllerEvent = unsafe { event.cbutton }.into();
                 self.controller_event_handlers.call_handlers(con);
             }
-            bind::SDL_EventType_SDL_CONTROLLERDEVICEADDED
-            | bind::SDL_EventType_SDL_CONTROLLERDEVICEREMOVED
-            | bind::SDL_EventType_SDL_CONTROLLERDEVICEREMAPPED => {
+            bind::SDL_CONTROLLERDEVICEADDED
+            | bind::SDL_CONTROLLERDEVICEREMOVED
+            | bind::SDL_CONTROLLERDEVICEREMAPPED => {
                 let con: ControllerEvent = unsafe { event.cdevice }.into();
                 self.controller_event_handlers.call_handlers(con);
             }
-            bind::SDL_EventType_SDL_JOYAXISMOTION => {
+            bind::SDL_JOYAXISMOTION => {
                 let joy: JoystickEvent = unsafe { event.jaxis }.into();
                 self.joystick_event_handlers.call_handlers(joy);
             }
-            bind::SDL_EventType_SDL_JOYBALLMOTION => {
+            bind::SDL_JOYBALLMOTION => {
                 let joy: JoystickEvent = unsafe { event.jball }.into();
                 self.joystick_event_handlers.call_handlers(joy);
             }
-            bind::SDL_EventType_SDL_JOYBUTTONDOWN | bind::SDL_EventType_SDL_JOYBUTTONUP => {
+            bind::SDL_JOYBUTTONDOWN | bind::SDL_JOYBUTTONUP => {
                 let joy: JoystickEvent = unsafe { event.jbutton }.into();
                 self.joystick_event_handlers.call_handlers(joy);
             }
-            bind::SDL_EventType_SDL_JOYDEVICEADDED | bind::SDL_EventType_SDL_JOYDEVICEREMOVED => {
+            bind::SDL_JOYDEVICEADDED | bind::SDL_JOYDEVICEREMOVED => {
                 let joy: JoystickEvent = unsafe { event.jdevice }.into();
                 self.joystick_event_handlers.call_handlers(joy);
             }
-            bind::SDL_EventType_SDL_JOYHATMOTION => {
+            bind::SDL_JOYHATMOTION => {
                 let joy: JoystickEvent = unsafe { event.jhat }.into();
                 self.joystick_event_handlers.call_handlers(joy);
             }
-            bind::SDL_EventType_SDL_AUDIODEVICEADDED
-            | bind::SDL_EventType_SDL_AUDIODEVICEREMOVED => {
+            bind::SDL_AUDIODEVICEADDED | bind::SDL_AUDIODEVICEREMOVED => {
                 let audio = unsafe { event.adevice }.into();
                 self.audio_device_event_handlers.call_handlers(audio);
             }
-            bind::SDL_EventType_SDL_DROPFILE
-            | bind::SDL_EventType_SDL_DROPTEXT
-            | bind::SDL_EventType_SDL_DROPBEGIN
-            | bind::SDL_EventType_SDL_DROPCOMPLETE => {
+            bind::SDL_DROPFILE
+            | bind::SDL_DROPTEXT
+            | bind::SDL_DROPBEGIN
+            | bind::SDL_DROPCOMPLETE => {
                 let drop = unsafe { event.drop }.into();
                 self.drop_event_handlers.call_handlers(drop);
             }
-            bind::SDL_EventType_SDL_MULTIGESTURE => {
+            bind::SDL_MULTIGESTURE => {
                 let gesture = unsafe { event.mgesture }.into();
                 self.gesture_event_handlers.call_handlers(gesture);
             }
-            bind::SDL_EventType_SDL_DOLLARGESTURE => {
+            bind::SDL_DOLLARGESTURE => {
                 let gesture = unsafe { event.dgesture }.into();
                 self.gesture_event_handlers.call_handlers(gesture);
             }
