@@ -57,7 +57,7 @@ impl std::fmt::Debug for Haptic {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         f.debug_struct("Haptic")
             .field("name", &self.name())
-            .finish()
+            .finish_non_exhaustive()
     }
 }
 
