@@ -72,9 +72,9 @@ impl From<bind::SDL_BlendMode> for BlendMode {
     fn from(raw: bind::SDL_BlendMode) -> Self {
         use BlendMode::*;
         match raw {
-            bind::SDL_BlendMode_SDL_BLENDMODE_BLEND => AlphaBlend,
-            bind::SDL_BlendMode_SDL_BLENDMODE_ADD => Add,
-            bind::SDL_BlendMode_SDL_BLENDMODE_MOD => Mul,
+            bind::SDL_BLENDMODE_BLEND => AlphaBlend,
+            bind::SDL_BLENDMODE_ADD => Add,
+            bind::SDL_BLENDMODE_MOD => Mul,
             _ => None,
         }
     }
@@ -84,10 +84,10 @@ impl From<BlendMode> for bind::SDL_BlendMode {
     fn from(raw: BlendMode) -> Self {
         use BlendMode::*;
         match raw {
-            AlphaBlend => bind::SDL_BlendMode_SDL_BLENDMODE_BLEND,
-            Add => bind::SDL_BlendMode_SDL_BLENDMODE_ADD,
-            Mul => bind::SDL_BlendMode_SDL_BLENDMODE_MOD,
-            None => bind::SDL_BlendMode_SDL_BLENDMODE_NONE,
+            AlphaBlend => bind::SDL_BLENDMODE_BLEND,
+            Add => bind::SDL_BLENDMODE_ADD,
+            Mul => bind::SDL_BLENDMODE_MOD,
+            None => bind::SDL_BLENDMODE_NONE,
         }
     }
 }
