@@ -30,7 +30,7 @@ impl std::fmt::Debug for Renderer<'_> {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         f.debug_struct("Renderer")
             .field("window", &self.window)
-            .finish()
+            .finish_non_exhaustive()
     }
 }
 
